==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/NativeUIDropDown.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { NativeUIDisplayDensity_$type } from "./NativeUIDisplayDensity";
import { enumGetBox, EnumUtil, markType } from "./type";
/**
 * @hidden
 */
var NativeUIDropDown = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(NativeUIDropDown, _super);
    function NativeUIDropDown() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.az = null;
        return _this;
    }
    NativeUIDropDown.prototype.get_e = function () {
        return 4;
    };
    Object.defineProperty(NativeUIDropDown.prototype, "ay", {
        get: function () {
            var a = this.q(1);
            return a == null ? 1 : EnumUtil.getEnumValue(NativeUIDisplayDensity_$type, a);
        },
        set: function (a) {
            this.ak(1, enumGetBox(NativeUIDisplayDensity_$type, a));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NativeUIDropDown.prototype, "a0", {
        get: function () {
            return this.az;
        },
        set: function (a) {
            var b = this.az;
            this.az = a;
            if (this.az != null) {
                this.z(3, this.az);
            }
            else {
                this.ai(3, b);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NativeUIDropDown.prototype, "a2", {
        get: function () {
            var a = this.q(7);
            return a;
        },
        set: function (a) {
            this.ak(7, a);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NativeUIDropDown.prototype, "a1", {
        get: function () {
            var a = this.q(6);
            return a;
        },
        set: function (a) {
            this.ak(6, a);
        },
        enumerable: true,
        configurable: true
    });
    NativeUIDropDown.$t = markType(NativeUIDropDown, 'NativeUIDropDown', NativeUIComponent.$);
    return NativeUIDropDown;
}(NativeUIComponent));
export { NativeUIDropDown };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/NativeUIDropDown.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { NativeUIDisplayDensity_$type } from "./NativeUIDisplayDensity";
import { enumGetBox, EnumUtil, markType } from "./type";
/**
 * @hidden
 */
var NativeUIDropDown = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUIDropDown, _super);
    function NativeUIDropDown() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.bl = null;
        return _this;
    }
    NativeUIDropDown.prototype.get_e = function () {
        return 4;
    };
    Object.defineProperty(NativeUIDropDown.prototype, "bk", {
        get: function () {
            var a = this.ag(1);
            return a == null ? 1 : EnumUtil.getEnumValue(NativeUIDisplayDensity_$type, a);
        },
        set: function (a) {
            this.a4(1, enumGetBox(NativeUIDisplayDensity_$type, a));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIDropDown.prototype, "bm", {
        get: function () {
            return this.bl;
        },
        set: function (a) {
            var b = this.bl;
            this.bl = a;
            if (this.bl != b) {
                if (b != null) {
                    this.a2(3, b);
                }
                if (this.bl != null) {
                    this.aq(3, this.bl);
                }
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIDropDown.prototype, "bo", {
        get: function () {
            var a = this.ag(9);
            return a;
        },
        set: function (a) {
            this.a4(9, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIDropDown.prototype, "bn", {
        get: function () {
            var a = this.ag(8);
            return a;
        },
        set: function (a) {
            this.a4(8, a);
        },
        enumerable: false,
        configurable: true
    });
    NativeUIDropDown.$t = markType(NativeUIDropDown, 'NativeUIDropDown', NativeUIComponent.$);
    return NativeUIDropDown;
}(NativeUIComponent));
export { NativeUIDropDown };
